@@ -27,6 +27,7 @@ latex.register()
 
 # Index used for internally for each part of a name
 A_VON=0; A_LAST=1; A_FIRST=2; A_JR=3
+
 ##########################################################################################
 class BibItem(dict):
   """
@@ -49,14 +50,15 @@ class BibItem(dict):
       if normalize: self.normalize()
     self.encoding='utf8'
 
+
   def set(self, b, key=None):
     """
     Set the values of the object to those given by the dictionary.
     If b is not a valid dictionary it will return an empty object
     """
     t= self._verify_entry(b)
-    if t:
-      # Copy the dictionary
+    if t:                               # Copy the dictionary
+
       self.update(b)
 
       if key != None:
@@ -103,6 +105,10 @@ class BibItem(dict):
 
   def set_default_styles(self):
     default_html_style={
+      'fields': ['title', 'author', 'journal', 'volume','number', 'month', 'booktitle',
+                'chapter', 'address', 'edition', 'howpublished','school', 'institution',
+                'organization', 'publisher', 'series','firstpage','lastpage', 'issn','isbn',
+                 'year', '_code', 'doi',  'url',  'abstract'], 
       '_type'      :None,
       'author'     :(r'<span class="authors">',r'</span> '),
       'title'      :(r'<span class="title">',r'</span> '),             
@@ -133,6 +139,8 @@ class BibItem(dict):
       'abstract'   :(r'<div class="abstracts button" onClick="toggle('+"'"+self.key.lower()+"'"+')">ABS</div>\n<div class="abstract" id="'+ self.key.lower()+'">',r'</div>')
       }
     default_latex_style={
+      'fields':  ['_code', 'title', 'author', 'journal','booktitle','school','volume','number',
+                  'firstpage','lastpage','year','url','doi','abstract'], 
       'author'     : (r'\authors{',r'}. '),
       'title'      : (r' \textbf{',r'} '),
       'journal'    : (r' \emph{',r'} '),
@@ -148,7 +156,6 @@ class BibItem(dict):
       'abstract'   : None,
       '_code': None,
       }
-
     self.html_style =  default_html_style
     self.latex_style= default_latex_style
 
@@ -317,30 +324,47 @@ class BibItem(dict):
           s+= '-%s' % (p)
     return s
 
-  def to_bibtex(self, indent=2, width=80):
+  def to_format(self, bullet, style = {}, formato = 'bibtex'):
+    """Convert to different formats:
+    bibtex, latex, html, xml,...  each item.
+    
+    Arguments:
+    - `self`:
+    - `bullet`:
+    - `style`:
+    - `formato`:
+    """
+    
+
+  def to_bibtex(self, indent=2, width=80, fields = None):
     """
     Format an entry as a bibtex item and returns it as a string, the argument wrap is the length of the lines in output
     """
     
+    if fields == None:
+      fields = ['author','editor'] + helper.textualfields[:]
+
     initial_indent= indent*' '
     # Indent the values of the fields
     wrap= textwrap.TextWrapper(width=width,subsequent_indent= 3*initial_indent,break_long_words=False)
     s= '@%s{%s,\n' %(self['_type'].upper(),self['_code'])
 
     # Add list of authors
+    all_fields = fields
     for f in ['author','editor']:
-      if self.has_key(f):
-        autores= ' and '.join(self.get_authorsList(format=1,who=f))
-        wrap.initial_indent=initial_indent
-        s+= wrap.fill(f + ' = {' + autores +'},') + '\n'
+      if f in fields: 
+        all_fields.remove(f)
+        if self.has_key(f):
+          autores= ' and '.join(self.get_authorsList(format=1,who=f))
+          wrap.initial_indent=initial_indent
+          s+= wrap.fill(f + ' = {' + autores +'},') + '\n'
 
     # put braces around upper case in titles
-    textualfields = helper.textualfields[:]
     braces_field = ['title']
     for kk in braces_field: 
-      textualfields.remove(kk)
+      if kk in all_fields:  all_fields.remove(kk)
       if self.has_key(kk): 
-        tit= helper.removebraces(self[kk])
+        tit= helper.cap_rex.sub(r'\1', self[kk])
         f = tit[0]
         for  c in tit[1:]:
           if c.isupper():
@@ -349,8 +373,8 @@ class BibItem(dict):
         s += wrap.fill('%s = {%s},' % (kk , f))+'\n'
 
     # Some fields that are copied literally
-    for kk in textualfields:
-      if self.has_key(kk) and not kk.startswith('_'):
+    for kk in all_fields:
+      if self.has_key(kk) and not kk.startswith('_') and (kk not in ['author', 'editor']):
         if kk in helper.nowrapfields:  # Not wrap
           s+= '%s%s = {%s}, \n' % (initial_indent,kk , self[kk])
         else:
@@ -404,22 +428,26 @@ class BibItem(dict):
     Converts the item to html format with the given style The style is a pair (before,
     after) surrounding the corresponding field (except for authors)
     """
-    # textfields= ['journal','booktitle','series','school','volume','number','publisher','firstpage','lastpage','year','_code','url','doi','abstract']
-    textualfields = ['journal', 'volume','number', 'month', 'booktitle', 'chapter', 'address', 'edition', 'howpublished','school', 'institution', 'organization', 'publisher', 'series','firstpage','lastpage',
-                     'note', 'crossref', 'issn','isbn', 'year', 'keywords' ,'annote', '_code', 'doi',  'url',  'abstract']
+
+    fields = ['title', 'author', 'journal', 'volume','number', 'month', 'booktitle', 'chapter',
+                     'address', 'edition', 'howpublished','school', 'institution', 'organization',
+                     'publisher', 'series','firstpage','lastpage', 'note', 'crossref', 'issn','isbn',
+                     'year', 'keywords' ,'annote', '_code', 'doi',  'url',  'abstract']
 
     st= dict(self.html_style)
     st.update(style)
-    tipo= self.get('_type','article')
-    title= helper.handle_math(self.get_field('title',''))
+    if not st.has_key('fields'): st['fields'] = fields 
+
+    # Format the title
+    title = self.get_field('title','')
+    title= helper.handle_math(title)
     title= helper.removebraces(title)
-    if 'mastersthesis' == tipo:  title= 'Master Thesis. ' + title
-    elif 'phdthesis' == tipo:    title= 'Phd Thesis. ' + title
-
-    s= ''
     if title != '' and st.get('title',['','']) !=  None:
-      s+= title.strip().join(st.get('title',['','']))
+      title= title.strip().join(st.get('title',['','']))
+    else:
+      title = ''
 
+    # Format authors
     if self.has_key('author') and st.get('author')!= None:
       form_aut=''
       list_aut= self.get_authorsList()
@@ -429,14 +457,20 @@ class BibItem(dict):
       for a in list_aut:
         form_aut += '<span class="author">'+ a +'</span>, '
       form_aut= form_aut[:-2]
-      s+= form_aut.join(st.get('author',['','']))
+      autores= form_aut.join(st.get('author',['','']))
     
-    for field in textualfields:
-      if self.get_field(field,'') != '' and st.get(field,(' ',' ')) != None:
+    # Put all fields together
+    s = ''
+    for field in st['fields']:
+      if field == 'author':  value = autores
+      elif field == 'title':  value = title
+      elif self.get_field(field,'') != '' and st.get(field,(' ',' ')) != None:
         value= helper.handle_math(self.get_field(field,'').strip())
-        value=bibparse.helper.removebraces(value)
-        s+= value.join(st.get(field,[' ',' ']))
+        value=bibparse.helper.removebraces(value).join(st.get(field,[' ',' ']))
+      else: value = ''
+      s+= value
 
+    # Aca agrego algo al principio y al final del item completo (por ejemplo '<li>' )
     if st.get('_type',['','']) !=  None:
       s= s.strip().join(st.get('_type',['','']))
 
@@ -448,25 +482,32 @@ class BibItem(dict):
     As its name indicates, it converts bibtex data to a latex bibitem
     """
 
-    textfields= ['journal','booktitle','school','volume','number','firstpage','lastpage','year','url','doi','abstract']
+    fields= ['_code', 'title', 'author', 'journal','booktitle','school','volume','number','firstpage','lastpage','year','url','doi','abstract']
 
     st=dict(self.latex_style)
     st.update(style)
-    s=''
-    
-    if st.get('_code') !=  None:
-      s+= self.get('_code').join(st['_code'])
+    if not st.has_key('fields'): st['fields'] = fields 
+
+    # if st.get('_code') !=  None:
+    #   code= self.get('_code').join(st['_code'])
 
     if self.get('title','') != '' and st.get('title') !=  None:
-      s+= self.get('title').join(st['title'])
-
+      title= self.get('title').join(st['title'])
+    
     if self.get('author','') != '' and st.get('author') != None:
-      s+= ', '.join(self.get_authorsList()).join(st['author'])
+      autores= ', '.join(self.get_authorsList()).join(st['author'])
 
-    for field in textfields:
-      if self.get_field(field,'') != '' and st.get(field) != None:
-        s+= self.get_field(field,'').strip().join(st[field])
-    # return s.encode('latex')
+    s=''
+    for field in st['fields']:
+      if field == 'author':  value = autores
+      elif field == 'title':  value = title
+      elif self.get_field(field,'') != '' and st.get(field,(' ',' ')) != None:
+        value= helper.handle_math(self.get_field(field,'').strip())
+        value=bibparse.helper.removebraces(value).join(st.get(field,[' ',' ']))
+      else: value = ''
+      s += value
+      # if self.get_field(field,'') != '' and st.get(field) != None:
+      #   s+= self.get_field(field,'').strip().join(st[field])
     return s
 
   def display(self, fpp=sys.stdout):
