@@ -66,8 +66,6 @@ class BibList(dict):
     try:
       self.ListItems += blist.ListItems
       self.ListItems= list(set(self.ListItems))
-#       for k in blist.ListItems:
-#         if k not in self.ListItems:  self.ListItems.append(k)
     except:  pass
     try:     self.abbrevDict.update(blist.abbrevDict)
     except:  pass
@@ -266,14 +264,13 @@ class BibList(dict):
     """
     ncount=0
     st,db= bibitem.bibparse.parsefile(fname)
-
     if st != []:
       for k,v in st.iteritems():
         self.insertAbbrev(k, v)
-
+    
     self.keepAbbrevs = not ReplaceAbbrevs
     if db != None:
-      for k,v in db.iteritems():
+      for k,v in db.iteritems():          
         b1= bibitem.BibItem(bibitem.bibparse.replace_abbrevs(self.abbrevDict,dict(v)), normalize = normalize)
         key= b1.get_key()               # The key is generated
         if self.keepAbbrevs:  status= self.add_item(v, key)
@@ -308,33 +305,7 @@ class BibList(dict):
     for item in self.get_items():
       item.set_default_styles()
       
-  def output(self, fout=None, formato='short', verbose=True):
-    """
-    Export all entries to a fout file with default options. All strings are resolved.
-    following formats are defined:
-    short (default)
-    long
-    bibtex
-    latex
-    html
-    xml
-    """
-
-    if verbose:
-      print '# %d items to output' %(len(self.ListItems))
-    fform = formato.lower()[0]
-    if fform == 'b':  self.export_bibtex(fout)
-    elif fform == 'l' or fform == 't': self.export_latex(fout)
-    elif fform == 'h':  self.export_html(fout)
-    elif fform == 'x':  self.export_xml(fout)
-    else:
-      fi= helper.openfile(fout,'w')
-      if fform == 'f':   fi.write(str(self))
-      else:  fi.write(self.preview().encode(self.encoding))
-      helper.closefile(fi)
-
-
-  def to_bibtex(self, indent=2, width=80):
+  def to_bibtex(self, indent=2, width=80, fields=None):
     """
     Export all entries to a bibtex file. All strings are resolved.
     """
@@ -354,17 +325,18 @@ class BibList(dict):
       s+='\n\n'
 
     for l in self.sortedList:
-      s+= '%s\n' %(self.get_item(l).to_bibtex(width= width))
+      s+= '%s\n' %(self.get_item(l).to_bibtex(indent=indent, width=width, fields=fields))
       
     if not self.keepAbbrevs:      return s 
     else:      return helper.reg_defstrng.sub(r'\1\2',s)
 
 
-  def export_bibtex(self, fname=None,indent=2, width=80):
+  def export_bibtex(self, fname=None,indent=2, width=80, fields=None):
     """
     Export a bibliography (set of items) to a file in bibtex format:
     """
-    fi= helper.openfile(fname,'w');  fi.write(self.to_bibtex(width));  helper.closefile(fi)
+    fi= helper.openfile(fname,'w');  fi.write(self.to_bibtex(indent, width, fields));
+    helper.closefile(fi)
 
   ##############################
   def to_latex(self,style={}, label = r'\item'):
@@ -416,7 +388,7 @@ class BibList(dict):
       s+= '<li class="%s"> %s </li>\n' %(tipo, ss)
     return s
 
-  def export_html(self, fname=None, style={}, head='',tail='', separate_css='biblio.css',encoding='utf-8'):
+  def export_html(self, fname=None, style={}, head='',tail='', separate_css='biblio.css', css_style=None, encoding='utf-8'):
     """
     Export a bibliography (set of items) to a file in bibtex format: style is a dictionary
     (like in bibitem objects) where the values is a pair (open,close) to insert around the
@@ -425,7 +397,7 @@ class BibList(dict):
     separate_css may have the
     """
     # default style
-    css_style="""
+    def_css_style="""
 .title a,
 .title {font-weight: bold;	color :    #416DFF; }
 ol.bibliography li{	margin-bottom:0.5em;}
@@ -438,24 +410,26 @@ li.article .publisher {display:none;}
 .publisher:after {content:") ";}
 .year:before {content:" (";}
 .year:after {content:").";}
-.authors {font-weight:bol; display:list;}
+.authors {font-weight:bold; display:list;}
 .authors:after {content:". ";}
 .volume { font-weight: bold;}
 .book .volume: before { content: "Vol. ";}
 .number:before {content:":";}
 .button {display:inline; border: 3px ridge;line-height:2.2em;margin: 0pt 10pt 0pt 0pt;padding:1pt;}
-.masterthesis{content:"Master Thesis"}
-.phdthesis{content:"Phd Thesis"}
+.masterthesis:before{font-weight: bold;content:"Master Thesis"}
+.phdthesis:before{font-weight: bold;content:"Phd Thesis"}
 div.abstracts {display: inline; font-weight: bold; text-decoration : none;  border: 3px ridge;}
 div.abstract {display: none;padding: 0em 1% 0em 1%; border: 3px double rgb(130,100,110); text-align: justify;} 
     """
+    if css_style == None:  css_style= def_css_style
 
     if helper.is_string_like(separate_css):
-      fi=helper.openfile(separate_css,'w');  fi.write(css_style);  helper.closefile(fi)
-      name= os.path.commonprefix([os.path.dirname(fname),os.path.dirname(separate_css)])
-      print os.path.basename(separate_css)
-      name= os.path.join(name,separate_css[len(name):])
-      css='  <link title="new" rel="stylesheet" href="' + name + '" type="text/css">'
+      the_path, fname_css= os.path.split(separate_css)
+      fpath= os.path.dirname(fname)
+      the_path= os.path.normpath(os.path.join(fpath,the_path))
+      fname_css= os.path.join(the_path,fname_css)
+      css='  <link title="new" rel="stylesheet" href="' + separate_css + '" type="text/css">'
+      fi=helper.openfile(fname_css,'w');  fi.write(css_style);  helper.closefile(fi)
     else:
       css= '<style type="text/css">' +css_style + '</style>'
 
@@ -525,6 +499,39 @@ div.abstract {display: none;padding: 0em 1% 0em 1%; border: 3px double rgb(130,1
     s= head + self.to_xml(prefix=prefix) + tail
     fi= helper.openfile(fname,'w');  fi.write(s.encode('utf-8','xmlcharrefreplace'))
     helper.closefile(fi)
+
+  def output(self, fout=None, formato=None, verbose=True):
+    """
+    Export all entries to a fout file with default options. All strings are resolved.
+    following formats are defined:
+    short (default)
+    long
+    bibtex
+    latex
+    html
+    xml
+    """
+    def write_short(fout):
+      fi= helper.openfile(fout,'w'); fi.write(str(self)); helper.closefile(fi)
+
+    def write_full(fout):
+      fi= helper.openfile(fout,'w'); fi.write(self.preview().encode(self.encoding))
+      helper.closefile(fi)
+
+    exp_meth = {'b': self.export_bibtex,
+              'l': self.export_latex, 't': self.export_latex,
+              'h': self.export_html,  'x': self.export_xml,
+              's': write_short,       'f': write_full
+              }
+    if verbose:  print '# %d items to output' %(len(self.ListItems))
+    if formato != None: 
+      fform = formato.lower()[0]
+    else:
+      if (fout != None) and (fout != '-'):  fform = os.path.splitext(fout)[1][1].lower()
+      else:                                 fform = 's'
+    exp_meth[fform](fout)
+
+
 ##########################################################################################
 ##########################################################################################
     
