@@ -24,20 +24,9 @@ def process_pages(pages):
   """ Returns a 2-tuple (firstpage,lastpage) from a string"""
   pp=reg_pages.split(pages)
   firstpage=pp[0]
-  if len(pp)==2:
-    lastpage=pp[1]
-  else:
-    lastpage=''
+  if len(pp)==2:    lastpage=pp[1]
+  else:             lastpage=''
   return firstpage,lastpage
-# def process_pages(pages):
-#   """ Returns a 2-tuple (firstpage,lastpage) from a string"""
-#   pp=pages.split('-')
-#   firstpage=pp[0]
-#   if len(pp)==2:
-#     lastpage=pp[1]
-#   else:
-#     lastpage=''
-#   return firstpage,lastpage
 
 def bibtexauthor(data):
   """ Returns a list of authors where each author is a list of the form:
@@ -232,6 +221,8 @@ def parseentry(source):
     for n,d in ff:
       if n == 'author' or n == 'editor':
         entry[n]= bibtexauthor(d)
+      elif n == 'title' or n == 'abstract':
+        entry[n]= helper.capitalizestring(d)
       elif n== 'pages':
         entry['firstpage'],entry['lastpage']= process_pages(d)
       elif n == 'year':
